Learn R Programming

enrichwith (version 0.6)

enrich.link-glm: Enrich objects of class link-glm

Description

Enrich objects of class link-glm with further derivatives of linkinv with respect to eta.

Usage

# S3 method for `link-glm`
enrich(object, with = "all", ...)

Value

The object object of class link-glm

with extra components. get_enrichment_options.link-glm()

returns the components and their descriptions.

Arguments

object

an object of class link-glm

with

a character vector with enrichment options for object

...

extra arguments to be passed to the compute_* functions

Details

The enrich.link-glm method supports logit, probit, cauchit, cloglog, identity, log, sqrt, 1/mu^2, inverse, as well as the power family of links.

Examples

Run this code

# Example
elogit <- enrich(make.link("logit"), with = "inverse link derivatives")
str(elogit)
elogit$d2mu.deta
elogit$d3mu.deta

Run the code above in your browser using DataLab