get_bias_function: Generic method for extracting or computing a function that...

View source: R/enrich-package.R

get_bias_functionR Documentation

Generic method for extracting or computing a function that returns the bias for the parameters in modelling objects

Description

Generic method for extracting or computing a function that returns the bias for the parameters in modelling objects

Usage

get_bias_function(object, ...)

Arguments

object

the object to be enriched or the enriched object

...

currently not used


enrichwith documentation built on April 29, 2026, 5:08 p.m.