Learn R Programming

enrichwith (version 0.6)

get_dmodel_function.betareg: Function to compute/extract a dmodel function

Description

Function to compute/extract a dmodel function

Usage

# S3 method for betareg
get_dmodel_function(object, ...)

Arguments

object

an object of class betareg orenriched_betareg

...

currently not used

Details

The computed/extracted function has arguments

response

an optional numeric response vector at which to compute densities. Values must be in (0, 1), and the vector must have the same length as the fitted response. If missing, the fitted response is used

coefficients

the mean and precision regression coefficients at which the densities are computed. If missing, the maximum likelihood estimates are used

log

logical; if TRUE, logarithmic densities are returned