Learn R Programming

enrichwith (version 0.6)

get_dmodel_function.glm: Function to compute/extract a dmodel function

Description

Function to compute/extract a dmodel function

Usage

# S3 method for glm
get_dmodel_function(object, ...)

Arguments

object

an object of class glm orenriched_glm

...

currently not used

Details

The computed/extracted function has arguments

response

an optional response vector or matrix at which to compute densities. It must have the same shape as the response in the fitted model. If missing, the fitted response is used. For grouped binomial models, the row totals of the fitted response should be retained

coefficients

the regression coefficients at which the densities are computed. If missing then the maximum likelihood estimates are used

dispersion

the dispersion parameter at which the densities function is computed. If missing then the maximum likelihood estimate is used

log

logical; if TRUE, the logarithm of the density is returned