Learn R Programming

enrichwith (version 0.6)

get_enrichment_options.betareg: Available options for the enrichment objects of class betareg

Description

Available options for the enrichment objects of class betareg

Usage

# S3 method for betareg
get_enrichment_options(object, option, all_options = missing(option))

Value

an object of class enrichment_options

Arguments

object

the object to be enriched

option

a character vector listing the options for enriching the object

all_options

if TRUE then output a data frame with the available enrichment options, their descriptions, the names of the components that each option results in, and the names of the corresponding compute_* functions.

Details

A check is being made whether the requested option is available. No check is being made on whether the functions that produce the components exist.

Examples

Run this code
if (FALSE) {
get_enrichment_options.betareg(option = "all")
get_enrichment_options.betareg(all_options = TRUE)
}

Run the code above in your browser using DataLab