betareg/enriched_betaregFunction to compute/extract a function that returns the information
matrix for an object of class betareg/enriched_betareg
# S3 method for betareg
get_information_function(object, ...)an object of class betareg orenriched_betareg
currently not used
The computed/extracted function has arguments
the regression coefficients at which the information matrix is evaluated. If missing then the maximum likelihood estimates are used
should the function return the 'expected' or 'observed' information? Default is expected
Currently not used
If TRUE, then the Cholesky decomposition of the information matrix at the coefficients is returned
an optional numeric response vector with values in
(0, 1). It must have the same length as the response in the
fitted model. If missing, the fitted response is used