get_pmodel_function: Generic method for extracting or computing a pmodel function...

View source: R/enrich-package.R

get_pmodel_functionR Documentation

Generic method for extracting or computing a pmodel function for modelling objects

Description

Generic method for extracting or computing a pmodel function for modelling objects

Usage

get_pmodel_function(object, ...)

Arguments

object

the object to be enriched or the enriched object

...

currently not used


enrichwith documentation built on April 29, 2026, 5:08 p.m.