Learn R Programming

enrichwith (version 0.6)

get_pmodel_function.betareg: Function to compute/extract a pmodel function

Description

Function to compute/extract a pmodel function

Usage

# S3 method for betareg
get_pmodel_function(object, ...)

Arguments

object

an object of class betareg orenriched_betareg

...

currently not used

Details

The computed/extracted function has arguments

response

an optional numeric response vector at which to compute the distribution function. Values must be in (0, 1), and the vector must have the same length as the fitted response. If missing, the fitted response is used

coefficients

the mean and precision regression coefficients at which the distribution function is computed. If missing, the maximum likelihood estimates are used

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\)

log.p

logical; if TRUE, logarithmic probabilities are returned