Learn R Programming

enrichwith (version 0.6)

get_qmodel_function.betareg: Function to compute/extract a qmodel function

Description

Function to compute/extract a qmodel function

Usage

# S3 method for betareg
get_qmodel_function(object, ...)

Arguments

object

an object of class betareg orenriched_betareg

...

currently not used

Details

The computed/extracted function has arguments

p

a vector with one probability for each observation in the fitted model

coefficients

the mean and precision regression coefficients at which the quantiles are computed. If missing, the maximum likelihood estimates are used

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\)

log.p

logical; if TRUE, logarithmic probabilities are used