qmodel functionFunction to compute/extract a qmodel function
# S3 method for glm
get_qmodel_function(object, ...)an object of class glm orenriched_glm
currently not used
The computed/extracted function has arguments
a vector with one probability for each observation in the fitted model
the regression coefficients at which the quantiles are computed. If missing then the maximum likelihood estimates are used
the dispersion parameter at which the quantiles are computed. If missing then the maximum likelihood estimate is used
logical; if TRUE, the logarithm of the
probabilities is used
logical; if TRUE (default), probabilities
are P[X <= x] otherwise, P[X > x]