get_score_function: Generic method for extracting or computing a function that...

View source: R/enrich-package.R

get_score_functionR Documentation

Generic method for extracting or computing a function that returns the scores for modelling objects

Description

Generic method for extracting or computing a function that returns the scores for modelling objects

Usage

get_score_function(object, ...)

Arguments

object

the object to be enriched or the enriched object

...

currently not used


enrichwith documentation built on April 29, 2026, 5:08 p.m.