Learn R Programming

enrichwith (version 0.6)

get_score_function.betareg: Function to compute/extract a function that returns the scores (derivatives of the log-likelihood) for an object of class betareg/enriched_betareg

Description

Function to compute/extract a function that returns the scores (derivatives of the log-likelihood) for an object of class betareg/enriched_betareg

Usage

# S3 method for betareg
get_score_function(object, ...)

Arguments

object

an object of class betareg orenriched_betareg

...

currently not used

Details

The computed/extracted function has arguments

coefficients

the regression coefficients at which the scores are computed. If missing then the maximum likelihood estimates are used

response

an optional numeric response vector with values in (0, 1). It must have the same length as the response in the fitted model. If missing, the fitted response is used