dmodel functionFunction to compute/extract a dmodel function
# S3 method for betareg
get_dmodel_function(object, ...)an object of class betareg orenriched_betareg
currently not used
The computed/extracted function has arguments
an optional numeric response vector at which to
compute densities. Values must be in (0, 1), and the vector
must have the same length as the fitted response. If missing, the
fitted response is used
the mean and precision regression coefficients at which the densities are computed. If missing, the maximum likelihood estimates are used
logical; if TRUE, logarithmic densities are
returned