dmodel functionFunction to compute/extract a dmodel function
# S3 method for glm
get_dmodel_function(object, ...)an object of class glm orenriched_glm
currently not used
The computed/extracted function has arguments
an optional response vector or matrix at which to compute densities. It must have the same shape as the response in the fitted model. If missing, the fitted response is used. For grouped binomial models, the row totals of the fitted response should be retained
the regression coefficients at which the densities are computed. If missing then the maximum likelihood estimates are used
the dispersion parameter at which the densities function is computed. If missing then the maximum likelihood estimate is used
logical; if TRUE, the logarithm of the density is
returned