pmodel functionFunction to compute/extract a pmodel function
# S3 method for betareg
get_pmodel_function(object, ...)an object of class betareg orenriched_betareg
currently not used
The computed/extracted function has arguments
an optional numeric response vector at which to
compute the distribution function. Values must be in (0, 1),
and the vector must have the same length as the fitted response. If
missing, the fitted response is used
the mean and precision regression coefficients at which the distribution function is computed. If missing, the maximum likelihood estimates are used
logical; if TRUE (default), probabilities
are \(P[X \le x]\), otherwise, \(P[X > x]\)
logical; if TRUE, logarithmic probabilities are
returned