pmodel functionFunction to compute/extract a pmodel function
# S3 method for glm
get_pmodel_function(object, ...)an object of class glm orenriched_glm
currently not used
The computed/extracted function has arguments
an optional response vector or matrix at which to compute the distribution function. It must have the same shape as the response in the fitted model. If missing, the fitted response is used. For grouped binomial models, the row totals of the fitted response should be retained
the regression coefficients at which the distribution function are computed. If missing then the maximum likelihood estimates are used
the dispersion parameter at which the distribution function is computed. If missing then the maximum likelihood estimate is used
logical; if TRUE, the logarithm of the
distribution function is returned
logical; if TRUE (default), probabilities
are P[X <= x] otherwise, P[X > x]