qmodel functionFunction to compute/extract a qmodel function
# S3 method for betareg
get_qmodel_function(object, ...)an object of class betareg orenriched_betareg
currently not used
The computed/extracted function has arguments
a vector with one probability for each observation in the fitted model
the mean and precision regression coefficients at which the quantiles are computed. If missing, the maximum likelihood estimates are used
logical; if TRUE (default), probabilities
are \(P[X \le x]\), otherwise, \(P[X > x]\)
logical; if TRUE, logarithmic probabilities are
used