betareg/enriched_betaregFunction to compute/extract a function that returns the scores
(derivatives of the log-likelihood) for an object of class
betareg/enriched_betareg
# S3 method for betareg
get_score_function(object, ...)an object of class betareg orenriched_betareg
currently not used
The computed/extracted function has arguments
the regression coefficients at which the scores are computed. If missing then the maximum likelihood estimates are used
an optional numeric response vector with values in
(0, 1). It must have the same length as the response in the
fitted model. If missing, the fitted response is used